#
# spec file for package felix-gogo-command
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global bundle  org.apache.felix.gogo.command
Name:           felix-gogo-command
Version:        1.1.2
Release:        3.6
Summary:        Apache Felix Gogo command line shell for OSGi
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            http://felix.apache.org/documentation/subprojects/apache-felix-gogo.html
Source0:        https://repo1.maven.org/maven2/org/apache/felix/org.apache.felix.gogo.command/%{version}/%{bundle}-%{version}-source-release.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.felix:gogo-parent:pom:)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.felix:org.apache.felix.gogo.runtime)
BuildRequires:  mvn(org.osgi:org.osgi.service.log)
BuildRequires:  mvn(org.osgi:osgi.annotation)
BuildRequires:  mvn(org.osgi:osgi.core)
BuildArch:      noarch

%description
Apache Felix Gogo is a subproject of Apache Felix implementing a command
line shell for OSGi. It is used in many OSGi runtimes and servers.

This package implements a set of basic commands.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{bundle}-%{version}

%{mvn_file} : felix/%{bundle}

# Use provided scope because this is useful on OSGi frameworks other than Felix
%pom_change_dep :osgi.core :::provided
%pom_change_dep :osgi.annotation :::provided
%pom_change_dep :junit :::test
%pom_change_dep :mockito-core :::test

%build
%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Thu Oct 26 2023 Fridrich Strba <fstrba@suse.com>
- Build javadoc with source level 8
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Fri Feb 10 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 1.1.2
- Changes from 1.1.0 to 1.1.2
  * Improvement
    + [FELIX-6038] - pull Java 7 support back in for gogo runtime,
    shell and console
- Changes from 1.0.2 to 1.1.0
  * Bug
    + [FELIX-5143] - Gogo Command bundle should not include
    org.osgi.service.log classes
    + [FELIX-5958] - gogo command exports org.osgi.service.log
  * New Feature
    + [FELIX-5835] - Upgrade to JDK 8
    + [FELIX-5836] - Upgrade to OSGi r6
  * Improvement
    + [FELIX-5969] - remove transitive dependencies from gogo
    command
    + [FELIX-5970] - Add requirement & capabilities model so gogo
    can be resolved
    + [FELIX-5999] - cleanup compiler warnings
    + [FELIX-6002] - Remove legacy code in Gogo Command
    + [FELIX-6003] - Add some resolver checks to make sure
    @RequireGogo annotation works for both jline and shell
    + [FELIX-6007] - create a gogo bom
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Remove forcing of maven.compiler.release, since it is not needed
  any more
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Tue May  7 2019 Fridrich Strba <fstrba@suse.com>
- Intial packaging of felix-gogo-command 1.0.2
